/*
  extvitalmot.c

  $Id: extvitalmot.c,v 1.4 2004/06/18 22:18:01 paul_c Exp $

  Dispatcher of external motion functions for Vital Systems Motenc100 pci Board

  Modification history:

  3-Mar-2004 AAR Adapted to Vital Systems MOTENC100 pci baord from the Vigilant
    source.
  24-Mar-2002  P.C. created from STG sources.

  */

#include "extintf.h"            /* these decls */
#include "vital.h"                /* decls for stg implementation */

/* Uncomment any of the following declarations to inhibit
   the use of home switches or index pulses when homing, or to
   ignore limit switches if you don't have them. */

/* Uncomment NO_HOME_SWITCH if you want homing sequence to
   ignore the home switch, and only use the index pulse for homing.
   This has the effect of making the home switches always appear tripped. */
/* #define NO_HOME_SWITCH */

/* Uncomment NO_INDEX_PULSE if you want homing sequence to
   ignore the index pulse, and only use the home switch for homing.
   This has the effect of making the index pulse always appear present. */
/* #define NO_INDEX_PULSE */

/* Uncomment NO_LIMIT_SWITCH if you don't have limit switches.
   This has the effect of making the positive and negative travel
   limit switches never appear tripped. */
/* #define NO_LIMIT_SWITCH */


char *extModel()
{
    return "Vital Systems Inc PCI card";
}

int extMotInit(const char * stuff)
{
  return vitalMotInit(stuff);
}

int extAioInit(const char * stuff)
{
  return vitalAioInit(stuff);
}

int extDioInit(const char * stuff)
{
  return vitalDioInit(stuff);
}

int extMotQuit(void)
{
  return vitalMotQuit();
}

int extAioQuit(void) 
{
  return vitalAioQuit();
}

int extDioQuit(void)
{
  return vitalDioQuit();
}

int extMotCycle(const char * stuff)
{
  return 0;
}

int extAioWrite(int index, double volts)
{
  return vitalAioWrite(index, volts);
}

int extEncoderReadAll(int max, double * counts)
{
  return vitalEncoderReadAll(max, counts);
}

int extDacWrite(int max, double volts)
{
  return vitalDacWrite(max, volts);
}

int extDacWriteAll(int max, double * volts)
{
  return vitalDacWriteAll(max, volts);
}

// INDEX
int extEncoderSetIndexModel(unsigned int model)
{
  return vitalEncoderSetIndexModel(model);
}

int extEncoderResetIndex(int axis)
{
  return vitalEncoderResetIndex(axis);
}

int extEncoderReadLatch(int axis, int * flag)
{
#ifdef NO_INDEX_PULSE
  *flag = 1;
  return 0;
#else
  return vitalEncoderReadLatch(axis, flag);
#endif
}

int extMaxLimitSwitchRead(int axis, int * flag) 
{
#ifdef NO_LIMIT_SWITCH
  *flag = 0;
  return 0;
#else
  return vitalMaxLimitSwitchRead(axis, flag);
#endif
}

int extMinLimitSwitchRead(int axis, int * flag) 
{
#ifdef NO_LIMIT_SWITCH
  *flag = 0;
  return 0;
#else
  return vitalMinLimitSwitchRead(axis, flag);
#endif
}

int extHomeSwitchRead(int axis, int * flag) 
{
#ifdef NO_HOME_SWITCH
  *flag = 1;
  return 0;
#else
  return vitalHomeSwitchRead(axis, flag);
#endif
}

int extAmpEnable(int axis, int enable) // Turn amp on/off
{
  return vitalAmpEnable(axis, enable);
}

int extAmpFault(int axis, int * fault) // read amp fault bit
{
  return vitalAmpFault(axis, fault);
}

int extDioRead(int index, int *value) 
{
  return vitalDioRead(index, value);
}

int extDioWrite(int index, int value) 
{
  return vitalDioWrite(index, value);
}

int extDioCheck(int index, int *value)
{
  return vitalDioCheck(index, value);
}


// Stubbed functions..
extern unsigned int IO_BASE_ADDRESS;

int extBaseFind()
{
    return IO_BASE_ADDRESS;
}

int extDioMaxInputs()
{
    return 32;
}

int extAioStart(int index)
{
    return 0;
}

int extAioReady(void)
{
    return 0;
}

int extAioRead(int index, double *value)
{
    return 0;
}

int extEncoderReadLevel(int encoder, int *flag)
{
    return 0;
}

